==> vigicaen_0.15.5.tar.gz: vigicaen/tests/testthat/_snaps/tb_who.md <==
# basic use works

    Code
      tb_who(path_who = path_who, force = TRUE)
    Message
      
      -- tb_who() --------------------------------------------------------------------
      i Creating WHO Drug tables.
      This process must only be done once per database version.
      =>----------------------------- percent, seconds | Read MP.txt 
      ==>---------------------------- percent, seconds | Split mp 
      ====>-------------------------- percent, seconds | Write mp.parquet 
      =====>------------------------- percent, seconds | Read PP.txt 
      ======>------------------------ percent, seconds | Split pp 
      ========>---------------------- percent, seconds | Write pp.parquet 
      =========>--------------------- percent, seconds | Read ThG.txt 
      ==========>-------------------- percent, seconds | Split thg 
      ==========>-------------------- percent, seconds | Write thg.parquet 
      ===========>------------------- percent, seconds | Read ING.txt 
      ============>------------------ percent, seconds | Split ing 
      ==============>---------------- percent, seconds | Write ing.parquet 
      ===============>--------------- percent, seconds | Read SRCE.txt 
      ================>-------------- percent, seconds | Split srce 
      ================>-------------- percent, seconds | Write srce.parquet 
      =================>------------- percent, seconds | Read ORG.txt 
      ==================>------------ percent, seconds | Split org 
      ==================>------------ percent, seconds | Write org.parquet 
      ===================>----------- percent, seconds | Read CCODE.txt 
      ====================>---------- percent, seconds | Split ccode 
      ======================>-------- percent, seconds | Write ccode.parquet 
      ========================>------ percent, seconds | Read ATC.txt 
      ========================>------ percent, seconds | Split atc 
      ========================>------ percent, seconds | Write atc.parquet 
      =========================>----- percent, seconds | Read SUN.txt 
      =========================>----- percent, seconds | Split sun 
      =========================>----- percent, seconds | Write sun.parquet 
      ==========================>---- percent, seconds | Read PF.txt 
      ==========================>---- percent, seconds | Split pf 
      ==========================>---- percent, seconds | Write pf.parquet 
      ==========================>---- percent, seconds | Read STR.txt 
      ===========================>--- percent, seconds | Split str 
      ===========================>--- percent, seconds | Write str.parquet 
      ===========================>--- percent, seconds | Read PRG.txt 
      ============================>-- percent, seconds | Split prg 
      ============================>-- percent, seconds | Write prg.parquet 
      ============================>-- percent, seconds | Read PRT.txt 
      ============================>-- percent, seconds | Split prt 
      =============================>- percent, seconds | Write prt.parquet 
      =============================>- percent, seconds | Read Unit-X.txt 
      =============================>- percent, seconds | Split unitx 
      ==============================> percent, seconds | Write unitx.parquet 
      ==============================> percent, seconds | Done 
      

---

    Code
      tb_who(path_who = path_who_no_slash, force = TRUE)
    Message
      
      -- tb_who() --------------------------------------------------------------------
      i Creating WHO Drug tables.
      This process must only be done once per database version.
      =>----------------------------- percent, seconds | Read MP.txt 
      ==>---------------------------- percent, seconds | Split mp 
      ====>-------------------------- percent, seconds | Write mp.parquet 
      =====>------------------------- percent, seconds | Read PP.txt 
      ======>------------------------ percent, seconds | Split pp 
      ========>---------------------- percent, seconds | Write pp.parquet 
      =========>--------------------- percent, seconds | Read ThG.txt 
      ==========>-------------------- percent, seconds | Split thg 
      ==========>-------------------- percent, seconds | Write thg.parquet 
      ===========>------------------- percent, seconds | Read ING.txt 
      ============>------------------ percent, seconds | Split ing 
      ==============>---------------- percent, seconds | Write ing.parquet 
      ===============>--------------- percent, seconds | Read SRCE.txt 
      ================>-------------- percent, seconds | Split srce 
      ================>-------------- percent, seconds | Write srce.parquet 
      =================>------------- percent, seconds | Read ORG.txt 
      ==================>------------ percent, seconds | Split org 
      ==================>------------ percent, seconds | Write org.parquet 
      ===================>----------- percent, seconds | Read CCODE.txt 
      ====================>---------- percent, seconds | Split ccode 
      ======================>-------- percent, seconds | Write ccode.parquet 
      ========================>------ percent, seconds | Read ATC.txt 
      ========================>------ percent, seconds | Split atc 
      ========================>------ percent, seconds | Write atc.parquet 
      =========================>----- percent, seconds | Read SUN.txt 
      =========================>----- percent, seconds | Split sun 
      =========================>----- percent, seconds | Write sun.parquet 
      ==========================>---- percent, seconds | Read PF.txt 
      ==========================>---- percent, seconds | Split pf 
      ==========================>---- percent, seconds | Write pf.parquet 
      ==========================>---- percent, seconds | Read STR.txt 
      ===========================>--- percent, seconds | Split str 
      ===========================>--- percent, seconds | Write str.parquet 
      ===========================>--- percent, seconds | Read PRG.txt 
      ============================>-- percent, seconds | Split prg 
      ============================>-- percent, seconds | Write prg.parquet 
      ============================>-- percent, seconds | Read PRT.txt 
      ============================>-- percent, seconds | Split prt 
      =============================>- percent, seconds | Write prt.parquet 
      =============================>- percent, seconds | Read Unit-X.txt 
      =============================>- percent, seconds | Split unitx 
      ==============================> percent, seconds | Write unitx.parquet 
      ==============================> percent, seconds | Done

==> vigicaen_0.15.6.tar.gz: vigicaen/tests/testthat/_snaps/tb_who.md <==
# basic use works

    Code
      tb_who(path_who = path_who, force = TRUE)
    Message
      
      -- tb_who() --------------------------------------------------------------------
      i Creating WHO Drug tables.
      This process must only be done once per database version.
      =>----------------------------- percent, seconds | Read MP.txt 
      ==>---------------------------- percent, seconds | Split mp 
      ====>-------------------------- percent, seconds | Write mp.parquet 
      =====>------------------------- percent, seconds | Read PP.txt 
      ======>------------------------ percent, seconds | Split pp 
      ========>---------------------- percent, seconds | Write pp.parquet 
      =========>--------------------- percent, seconds | Read ThG.txt 
      ==========>-------------------- percent, seconds | Split thg 
      ==========>-------------------- percent, seconds | Write thg.parquet 
      ===========>------------------- percent, seconds | Read ING.txt 
      ============>------------------ percent, seconds | Split ing 
      ==============>---------------- percent, seconds | Write ing.parquet 
      ===============>--------------- percent, seconds | Read SRCE.txt 
      ================>-------------- percent, seconds | Split srce 
      ================>-------------- percent, seconds | Write srce.parquet 
      =================>------------- percent, seconds | Read ORG.txt 
      ==================>------------ percent, seconds | Split org 
      ==================>------------ percent, seconds | Write org.parquet 
      ===================>----------- percent, seconds | Read CCODE.txt 
      ====================>---------- percent, seconds | Split ccode 
      ======================>-------- percent, seconds | Write ccode.parquet 
      ========================>------ percent, seconds | Read ATC.txt 
      ========================>------ percent, seconds | Split atc 
      ========================>------ percent, seconds | Write atc.parquet 
      =========================>----- percent, seconds | Read SUN.txt 
      =========================>----- percent, seconds | Split sun 
      =========================>----- percent, seconds | Write sun.parquet 
      ==========================>---- percent, seconds | Read PF.txt 
      ==========================>---- percent, seconds | Split pf 
      ==========================>---- percent, seconds | Write pf.parquet 
      ==========================>---- percent, seconds | Read STR.txt 
      ===========================>--- percent, seconds | Split str 
      ===========================>--- percent, seconds | Write str.parquet 
      ===========================>--- percent, seconds | Read PRG.txt 
      ============================>-- percent, seconds | Split prg 
      ============================>-- percent, seconds | Write prg.parquet 
      ============================>-- percent, seconds | Read PRT.txt 
      ============================>-- percent, seconds | Split prt 
      =============================>- percent, seconds | Write prt.parquet 
      =============================>- percent, seconds | Read Unit-X.txt 
      =============================>- percent, seconds | Split unitx 
      ==============================> percent, seconds | Write unitx.parquet 
      ==============================> percent, seconds | Done 
      

---

    Code
      tb_who(path_who = path_who_no_slash, force = TRUE)
    Message
      
      -- tb_who() --------------------------------------------------------------------
      i Creating WHO Drug tables.
      This process must only be done once per database version.
      =>----------------------------- percent, seconds | Read MP.txt 
      ==>---------------------------- percent, seconds | Split mp 
      ====>-------------------------- percent, seconds | Write mp.parquet 
      =====>------------------------- percent, seconds | Read PP.txt 
      ======>------------------------ percent, seconds | Split pp 
      ========>---------------------- percent, seconds | Write pp.parquet 
      =========>--------------------- percent, seconds | Read ThG.txt 
      ==========>-------------------- percent, seconds | Split thg 
      ==========>-------------------- percent, seconds | Write thg.parquet 
      ===========>------------------- percent, seconds | Read ING.txt 
      ============>------------------ percent, seconds | Split ing 
      ==============>---------------- percent, seconds | Write ing.parquet 
      ===============>--------------- percent, seconds | Read SRCE.txt 
      ================>-------------- percent, seconds | Split srce 
      ================>-------------- percent, seconds | Write srce.parquet 
      =================>------------- percent, seconds | Read ORG.txt 
      ==================>------------ percent, seconds | Split org 
      ==================>------------ percent, seconds | Write org.parquet 
      ===================>----------- percent, seconds | Read CCODE.txt 
      ====================>---------- percent, seconds | Split ccode 
      ======================>-------- percent, seconds | Write ccode.parquet 
      ========================>------ percent, seconds | Read ATC.txt 
      ========================>------ percent, seconds | Split atc 
      ========================>------ percent, seconds | Write atc.parquet 
      =========================>----- percent, seconds | Read SUN.txt 
      =========================>----- percent, seconds | Split sun 
      =========================>----- percent, seconds | Write sun.parquet 
      ==========================>---- percent, seconds | Read PF.txt 
      ==========================>---- percent, seconds | Split pf 
      ==========================>---- percent, seconds | Write pf.parquet 
      ==========================>---- percent, seconds | Read STR.txt 
      ===========================>--- percent, seconds | Split str 
      ===========================>--- percent, seconds | Write str.parquet 
      ===========================>--- percent, seconds | Read PRG.txt 
      ============================>-- percent, seconds | Split prg 
      ============================>-- percent, seconds | Write prg.parquet 
      ============================>-- percent, seconds | Read PRT.txt 
      ============================>-- percent, seconds | Split prt 
      =============================>- percent, seconds | Write prt.parquet 
      =============================>- percent, seconds | Read Unit-X.txt 
      =============================>- percent, seconds | Split unitx 
      ==============================> percent, seconds | Write unitx.parquet 
      ==============================> percent, seconds | Done 
      

# path_who exists before working on tables

    Code
      tb_who(path_who = wrong_path, force = TRUE)
    Condition <no_dir>
      Error in `tb_who()`:
      ! `path_who` must exist.
      x "/a/wrong/filepath/" does not exist.
